# The Contributor Guide

## Questions

It's better to ask on [Stack Overflow]([https://stackoverflow.com/questions/tagged/aplex]), but not limited to. Remember to add a tag of aplex.

## Bug Reports

It's better to tell me but not limited to:

- What you expected to happen
- What actually happens (include the complete traceback)
- How to reproduce the issue
- Your python and aplex versions

## Pull requests

Keep the code style consistent. This package  follows [Google Style Guide](https://github.com/google/styleguide/blob/gh-pages/pyguide.md).